//
//   @file    fploughshare.cxx         
//   
//
//   @author M Sutton
//
//   $Id: fploughshare.cxx, v0.0   Thu 19 Jul 2018 20:11:36 CEST sutt $
//
//   Copyright (C) 2018 M Sutton (sutt@cern.ch)    


#include <string>
#include <cstdio>


#include "ploughshare.h"


/// int to string function - not non c++11 compliant compilers
std::string itoa( int i ) {
  char a[16]; // a 32 bit integer not longer than 16 digits
  sprintf( a, "%d", i );
  return a;
}

/// copy string to a fortran like string
 
void ctofstring( const std::string& s, char* fs, size_t flen ) {
  size_t i=0;
  if ( s.size()>flen ) throw ploughshare::exception( "string length (" + itoa(flen)+") not long enough to store string: "+s );
  while ( i<s.size() ) { fs[i] = s[i]; i++; } 
  while ( i<flen ) fs[i++] = 0;
}



/// this is the central data base
/// it is static so noone else can 
/// mess with it

static ploughshare p;


extern "C" int fetch_( char* s, int _len ) { 
  return p.fetch( std::string( s, 0, _len ) );
}


extern "C" int datsetsize_( char* s, int _len ) { 
  return p.size( std::string( s, 0, _len ) );
}


extern "C"  void getdatasetpath_( const char* datasetin, char* gridpath, int _dlen, int _glen) {
  ctofstring( p.path( std::string( datasetin, 0, _dlen ) ), gridpath, _glen ); 
}


extern "C"  void getgridpath_( const char* datasetin, const int& igrid,  char* gridpath, int _dlen, int _glen) {
  ctofstring( p.grids( std::string( datasetin, 0, _dlen ) ).at(igrid), gridpath, _glen ); 
}





